"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var pure_1 = require("../../utils/pure");
var ReactDOM = require("react-dom");
var withTheme_1 = require("../../utils/withTheme");
var ButtonIcon_1 = require("../ButtonIcon/ButtonIcon");
var Input_1 = require("../input/Input");
var Control_1 = require("../Control/Control");
var Holdable_1 = require("../Holdable/Holdable");
exports.STEPPABLE_INPUT = Symbol('SteppableInput');
var RawSteppableInput = /** @class */ (function (_super) {
    tslib_1.__extends(RawSteppableInput, _super);
    function RawSteppableInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {};
        _this.onClearClick = function () {
            var onClear = _this.props.onClear;
            onClear && onClear();
        };
        _this.onIncrementClick = function () {
            var onIncrement = _this.props.onIncrement;
            onIncrement && onIncrement();
        };
        _this.onDecrementClick = function () {
            var onDecrement = _this.props.onDecrement;
            onDecrement && onDecrement();
        };
        _this.onButtonMouseDown = function (e) {
            if (_this.state.isFocused) {
                e.preventDefault();
            }
        };
        _this.onFocus = function (e) {
            if (!_this.props.isDisabled && !_this.state.isFocused) {
                _this.setState({
                    isFocused: true,
                });
                _this.props.onFocus && _this.props.onFocus(e);
            }
        };
        _this.onBlur = function (e) {
            if (!_this.props.isDisabled && _this.state.isFocused) {
                _this.setState({
                    isFocused: false,
                });
                _this.props.onBlur && _this.props.onBlur(e);
            }
        };
        _this.onKeyDown = function (e) {
            if (!_this.props.isDisabled) {
                switch (e.keyCode) {
                    case Control_1.KeyCode.Up: {
                        _this.props.onIncrement && _this.props.onIncrement();
                        break;
                    }
                    case Control_1.KeyCode.Down: {
                        _this.props.onDecrement && _this.props.onDecrement();
                        break;
                    }
                }
                _this.props.onKeyDown && _this.props.onKeyDown(e);
            }
        };
        _this.onWheel = function (e) {
            var _a = _this.props, isDisabled = _a.isDisabled, onIncrement = _a.onIncrement, onDecrement = _a.onDecrement;
            var isFocused = _this.state.isFocused;
            if (!isDisabled && isFocused) {
                e.preventDefault(); //block v-scrolling
                if (e.deltaY < 0) {
                    onIncrement && onIncrement();
                }
                else {
                    onDecrement && onDecrement();
                }
            }
        };
        return _this;
    }
    RawSteppableInput.prototype.componentDidUpdate = function (prevProps) {
        if (prevProps.onClear && !this.props.onClear) {
            //when removing clear button from dom component wierdly loses focus
            var element = ReactDOM.findDOMNode(this);
            element.focus();
        }
    };
    RawSteppableInput.prototype.render = function () {
        var _a = this.props, isDisabled = _a.isDisabled, error = _a.error, theme = _a.theme, children = _a.children, tabIndex = _a.tabIndex, decrementIcon = _a.decrementIcon, incrementIcon = _a.incrementIcon, clearIcon = _a.clearIcon, onIncrement = _a.onIncrement, onDecrement = _a.onDecrement, onClear = _a.onClear, onClick = _a.onClick, Input = _a.Input, ButtonIcon = _a.ButtonIcon;
        var isFocused = this.state.isFocused;
        return (React.createElement(Input, { theme: theme.Input, type: "hidden", onFocus: this.onFocus, onBlur: this.onBlur, onKeyDown: this.onKeyDown, onClick: onClick, onWheel: this.onWheel, isDisabled: isDisabled, error: error, onValueChange: function () { return console.log('onchange'); }, tabIndex: isFocused || isDisabled ? -1 : tabIndex || 0 },
            React.createElement("div", { className: theme.inner },
                children,
                onClear &&
                    clearIcon && (React.createElement(ButtonIcon, { icon: clearIcon, isFlat: true, theme: theme.ClearButtonIcon, onClick: this.onClearClick, onMouseDown: this.onButtonMouseDown, isDisabled: isDisabled, tabIndex: -1 })),
                onDecrement &&
                    decrementIcon && (React.createElement(Holdable_1.Holdable, { onHold: onDecrement },
                    React.createElement(ButtonIcon, { icon: decrementIcon, theme: theme.ButtonIcon, onClick: this.onDecrementClick, onMouseDown: this.onButtonMouseDown, isDisabled: isDisabled, tabIndex: -1 }))),
                onIncrement &&
                    incrementIcon && (React.createElement(Holdable_1.Holdable, { onHold: onIncrement },
                    React.createElement(ButtonIcon, { icon: incrementIcon, theme: theme.ButtonIcon, onClick: this.onIncrementClick, onMouseDown: this.onButtonMouseDown, isDisabled: isDisabled, tabIndex: -1 }))))));
    };
    RawSteppableInput.defaultProps = {
        Input: Input_1.Input,
        ButtonIcon: ButtonIcon_1.ButtonIcon,
    };
    RawSteppableInput = tslib_1.__decorate([
        pure_1.PURE
    ], RawSteppableInput);
    return RawSteppableInput;
}(React.Component));
exports.SteppableInput = withTheme_1.withTheme(exports.STEPPABLE_INPUT)(RawSteppableInput);
function checkParentsUpTo(node, checkNode, upToNode) {
    if (!node || !checkNode || !upToNode) {
        return false;
    }
    else if (node === upToNode) {
        return false;
    }
    else if (node === checkNode) {
        return true;
    }
    else {
        return checkParentsUpTo(node.parentElement, checkNode, upToNode);
    }
}
exports.checkParentsUpTo = checkParentsUpTo;
//# sourceMappingURL=SteppableInput.js.map